/**
 * @file
 * Provides Slick Browser view exposed form utilitiy functions.
 */

(function ($, Drupal) {

  'use strict';

  var _idSubmit = 'sb__autosubmit';
  var _idSelect = 'sb--autoselect';
  var _onSubmit = _idSubmit + '--on';
  var _onSelect = _idSelect + '--on';
  var _elSubmit = '.' + _idSubmit + ':not(.' + _onSubmit + ')';
  var _elSelect = '.' + _idSelect + ':not(.' + _onSelect + ')';

  Drupal.slickBrowser = Drupal.slickBrowser || {};

  /**
   * Slick Browser utility functions.
   *
   * @param {HTMLElement} el
   *   The form-radio HTML element.
   */
  function sbAutoSubmit(el) {
    var $el = $(el);
    var $view = $el.closest('.view--sb');
    var val = $el.find('.form-radio:checked').val().replace('_', '-');

    $view.addClass('view--sb-filter-' + val);
    if ($view.find('.view-empty').length) {
      $view.addClass('view--sb-filter-empty');
    }

    $el.find('.form-radio').each(function () {
      var $radio = $(this);
      val = $radio.val().replace('_', '-');

      $radio.on('change', function () {
        $view.removeClass('view--sb-filter-' + val);
        $view.addClass('view--sb-filter-' + val);

        $('.is-filter-checked', $el).removeClass('is-filter-checked');
        $radio.parent().addClass('is-filter-checked');

        $el.find('.form-submit').trigger('click');
      });
    });

    $el.addClass(_onSubmit);
  }

  /**
   * Autu select bundle if it is a Media browser to save another click.
   *
   * @param {HTMLElement} widget
   *   The .sb--autoselect HTML element.
   */
  function sbAutoSelect(widget) {
    var $widget = $(widget);
    var $iframe = $('iframe[name*="slick_browser"]', widget);
    var $doc;
    var entityTypeId = $widget.data('sbEntityTypeId');
    var bundle = $widget.data('sbBundle');
    var $autoSubmit;
    var $radio;

    var autoSelect = function () {
      $doc = $iframe.contents();
      $autoSubmit = $('.sb__autosubmit', $doc);
      $radio = $('.form-radio[value="' + bundle + '"]', $autoSubmit);

      // We are outside node form, at Media browser containing media bundle.
      if ($radio.length) {
        $radio.trigger('click');
      }
    };

    if (entityTypeId === 'media') {
      $iframe.on('load', autoSelect);
    }
    $widget.addClass(_onSelect);
  }

  /**
   * Attaches Slick Browser view exposed form behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickBrowserAutoSubmit = {
    attach: function (context) {

      var me = Drupal.slickBrowser;
      context = me.context(context);

      me.once(context, _elSubmit, sbAutoSubmit);
      me.once(context, _elSelect, sbAutoSelect);

    }
  };

})(jQuery, Drupal);
