/**
 * @file
 * Provides Slick Browser utilitiy functions.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.slickBrowser = Drupal.slickBrowser || {};

  var _onTabs = 'form--tabs--on';
  var _element = '.form--tabs:not(.' + _onTabs + ')';
  var _tabsTimer;

  /**
   * Slick Browser utility functions.
   *
   * @param {HTMLElement} form
   *   The Entity Browser form HTML element.
   */
  function sbTabs(form) {
    var me = Drupal.slickBrowser;
    var $form = $(form);
    var pos = $form.data('tabsPos');
    var $tabs = $('.eb-tabs', form);

    // It seems taking time to build JS tabs.
    if (pos) {
      if ($tabs.length) {
        $tabs.prependTo('#edit-' + pos);
      }
      else {
        window.clearTimeout(_tabsTimer);
        _tabsTimer = window.setTimeout(function () {
          $('.eb-tabs', form).prependTo('#edit-' + pos);
        }, 800);
      }
    }

    // Adds loading indicator whenever a tab is clicked.
    $form.on('click', '.eb-tabs a:not(.is-active)', me.loading);
    $form.on('click mousedown', '.sb__header input', me.loading);
    $form.addClass(_onTabs);
  }

  /**
   * Attaches Slick Browser tabs behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickBrowserTabs = {
    attach: function (context) {

      var me = Drupal.slickBrowser;
      context = me.context(context);

      me.once(context, _element, sbTabs);
    }
  };

})(jQuery, Drupal);
